summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--driver/ppc/sn5s330.c12
1 files changed, 8 insertions, 4 deletions
diff --git a/driver/ppc/sn5s330.c b/driver/ppc/sn5s330.c
index 1c9b63f04f..5dbc02437b 100644
--- a/driver/ppc/sn5s330.c
+++ b/driver/ppc/sn5s330.c
@@ -277,10 +277,14 @@ static int sn5s330_init(int port)
return status;
}
- /* Set analog current limit delay to 200 us for both PP1 & PP2. */
- regval = (PPX_ILIM_DEGLITCH_0_US_200 << 3) | PPX_ILIM_DEGLITCH_0_US_200;
- status = i2c_write8(i2c_port, i2c_addr_flags,
- SN5S330_FUNC_SET11, regval);
+ /*
+ * Set analog current limit delay to 200 us for PP1,
+ * set 1000 us for PP2 for compatibility.
+ */
+ regval = (PPX_ILIM_DEGLITCH_0_US_200 << 3) |
+ PPX_ILIM_DEGLITCH_0_US_1000;
+ status = i2c_write8(i2c_port, i2c_addr_flags, SN5S330_FUNC_SET11,
+ regval);
if (status) {
CPRINTS("ppc p%d: Failed to set FUNC_SET11", port);
return status;